#
# spec file for package gnome-recipes
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-recipes
Version:        2.0.4+117
Release:        1.5
Summary:        A recipe app for GNOME
License:        GPL-3.0-or-later
Group:          Productivity/Other
URL:            https://wiki.gnome.org/Design/Apps/Recipes
Source0:        %{name}-%{version}.tar.xz

BuildRequires:  appstream-glib
BuildRequires:  fdupes
BuildRequires:  glib2-devel >= 2.42
BuildRequires:  gobject-introspection-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  itstool
BuildRequires:  libxml2-tools
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala-devel
BuildRequires:  pkgconfig(gnome-autoar-0)
BuildRequires:  pkgconfig(goa-1.0)
BuildRequires:  pkgconfig(gspell-1)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libcanberra)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(rest-0.7)

%description
GNOME Recipes is an easy-to-use application that will help you to discover what to cook
today, tomorrow, rest of the week and for your special occasions.

Recipes comes with a collection of recipes that have been collected by GNOME contributors
from all over the world. It also lets you store your own recipes, and share them with your
friends.

%package -n gnome-shell-search-provider-%{name}
Summary:        A recipe app for GNOME -- Search Provider for GNOME Shell
Group:          Productivity/Office/Organizers
Requires:       %{name} = %{version}
Requires:       gnome-shell
Supplements:    packageand(%{name}:gnome-shell)

%description -n gnome-shell-search-provider-%{name}
GNOME Recipes is an easy-to-use application that will help you to discover what to cook
today, tomorrow, rest of the week and for your special occasions.

Recipes comes with a collection of recipes that have been collected by GNOME contributors
from all over the world. It also lets you store your own recipes, and share them with your
friends.

This package contains a search provider to enable GNOME Shell to get
search results from Recipes.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-D autoar=yes \
	-D gspell=yes \
	-D canberra=yes \
	%{nil}
%meson_build

%install
%meson_install
%suse_update_desktop_file -r org.gnome.Recipes GTK GNOME Office ProjectManagement
%fdupes %{buildroot}%{_datadir}
%find_lang %{name} %{?no_lang_C}
%find_lang org.gnome.Recipes %{?no_lang_C}
%find_lang %{name}-data %{?no_lang_C}

%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/dbus-1/services/org.gnome.Recipes.service
%{_datadir}/metainfo/org.gnome.Recipes.appdata.xml
%{_datadir}/glib-2.0/schemas/org.gnome.Recipes.gschema.xml
%{_datadir}/mime/packages/org.gnome.Recipes-mime.xml
%{_datadir}/%{name}
%{_datadir}/help/C/org.gnome.Recipes/

%files -n gnome-shell-search-provider-%{name}
%dir %{_datadir}/gnome-shell
%dir %{_datadir}/gnome-shell/search-providers
%{_datadir}/gnome-shell/search-providers/org.gnome.Recipes-search-provider.ini

%files lang -f %{name}.lang -f %{name}-data.lang -f org.gnome.Recipes.lang

%changelog
* Sat Oct  5 2024 bjorn.lie@gmail.com
- Update to version 2.0.4+117:
  * meson: drop unused argument for i18n.merge_file()
  * Fix minor typos
  * help: Add one missing author (follow-up to previous 4eb2571)
  * help: Include file legal.xml instead of using <license> tags;
    add years
  * Fix a few more compiler warnings
  * recipes.db: Fix Tzatziki ingredient list
  * Fix deprecation warnings for use of GTimeVal
  * Revert "Fix deprecation warnings for use of GTimeVal"
  * Fix deprecation warnings for use of GTimeVal
  * build: Use i18n.merge_file for .desktop and .appdata
  * build: Read language lists from LINGUAS
  * build: Remove Makevars files
  * meson: Bump to a development version (2.0.5)
  * build: fix cross building
  * Updated translations.
* Mon Mar  9 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.0.4
  * Fix a few crasher bugs
  * Fix an issue where the chef dialog wouldn't reopen
    when closed using Esc key
  * Fix the Flatpak build and the CI build
  * Fix the build dependencies known to meson (make gio-unix-2.0 explicit)
  * Update the AppStream data
    (add OARS data, fix the SPDX license identifier, etc.)
  * Update the bug reporting URL to GNOME GitLab
  * Add a label for Halal recipes
  * Fix the labels on "White fish for people who don't like fish"
    so it doesn't claim to be vegetarian
  * Tweak the wording on two recipes in the Vegetarian category,
    now called "Gravy" and "Marinade"
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Wed Oct  2 2019 bjorn.lie@gmail.com
- Update to version 2.0.2+97:
  + help: Application menu has been replaced by menu button.
  + Replace Bugzilla by Gitlab URL in DOAP file.
  + Add halal category.
  + Minor bug and build fixes.
  + Updated translations.
- Switch to git checkout via source service, explicit commit.
- Drop gnome-recipes-nb-translations.patch: Fixed upstream.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sun Jan 28 2018 bjorn.lie@gmail.com
- Add gnome-recipes-nb-translations.patch: Update Norwegian Bokmål
  translations.
- Minor spec cleanup, use autosetup macro, pass explicit
  autoar=yes, gspell=yes and canberra=yes to meson, ensure we build
  the features we want.
* Sun Nov 12 2017 luc14n0@linuxmail.org
- Update to version 2.0.2:
  + Fixes:
  - A serious bug in version 2.0.0, which could cause all
    ingredients to lose their amounts when editing a recipe.
  - An issue where ingredients without amount would always get
    displayed with an errant '1' as amount.
  + Allow recipes to have long names.
  + New recipes: Tzatziki, Soy Chicken, Rice Maize Apple Cake.
  + Updated translations.
- Replace pkgconfig(gio-2.0) with glib2-devel BuildRequires:
  pkgconfig(*) glib-2.0 and gmodule-export-2.0 are native
  dependencies, but glib-2.0 is not listed in meson.build as
  dependency and gmodule-export-2.0 is but not used. And since
  gio-2.0, gio-unix-2.0, gmodule-2.0 and gobject-2.0 are being used
  but not listed in meson.build is better to use glib2-devel.
* Mon Oct 30 2017 dimstar@opensuse.org
- Update to version 2.0.0:
  + Unit conversion support has landed. There are new settings,
    volume-unit and weight-unit, which can be set to 'locale'
    (the default), 'metric' or 'imperial' to control how units are
    displayed. We are also formatting numbers in a human-friendly
    way and separate them into multiple units where appropriate.
  + Support for sharing shopping lists to the Todoist mobile app.
  + Updated translations.
- Add pkgconfig(goa-1.0) and pkgconfig(rest-0.7) BuildRequires: new
  dependencies for todoist integration.
- Drop gnome-recipes-fix-meson-options.patch: Fixed upstream.
- Drop glib2_gsettings_schema_, icon_theme_cache_ and
  desktop_database_ post/postun handling: this is now achieved by
  file triggers.
* Wed Oct 25 2017 malcolmlewis@opensuse.org
- Add gnome-recipes-fix-meson-options.patch: Change default to
  value in meson_options.txt for meson build >= 0.43.0.
- Change rpm group to Productivity/Other.
* Fri Jul 28 2017 zaitor@opensuse.org
- Update to version 1.6.2:
  + No NEWS, or ChangeLog provided from upstream.
* Thu Jun 22 2017 zaitor@opensuse.org
- Update to version 1.4.6:
  + No NEWS, or ChangeLog provided from upstream.
- Drop gnome-recipes-fix-build-without-git.patch: Fixed upstream.
* Tue May 23 2017 zaitor@opensuse.org
- Update to version 1.4.4:
  + No NEWS, or ChangeLog provided from upstream.
- Switch to meson buildsystem:
  + Add meson BuildRequires and macros, remove autotools macros.
- Add itstool and pkgconfig(libsoup-2.4) BuildRequires: New
  dependencies.
- Add gnome-recipes-fix-build-without-git.patch: Fix build, git
  should not be needed.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 1.0.0:
  + Add and edit your own recipes.
  + Share recipes with your friends.
  + Export and print shopping lists.
  + Adjust quantities based on the number of servings.
  + Mark recipes to cook later or add them to your favorites.
  + Add notes to recipes.
  + Hands-free cooking instruction mode.
  + Updated translations.
* Tue Mar 14 2017 dimstar@opensuse.org
- Update to version 0.22.0:
  + Add a way to go from shopping to cooking.
  + Confirm quitting with unsaved changes.
  + Confirm ending cooking mode with running timers.
  + Store ancillary data in GSettings.
  + Match Chef names when searching.
  + Add --verbose and --version commandline options.
  + Make dialogs non-maximizable on OS X.
  + Use a more traditional menubar on OS X.
  + Bug and memory leak fixes.
  + Updated translations.
- Add %%glib2_gsettings_schema_{post,postun} to the respective
  scriptlets to handle the new schema.
* Tue Mar 14 2017 dimstar@opensuse.org
- Add fdupes buildrequires and call over _datadir: eliminiate
  duplicate files.
* Sun Mar  5 2017 badshah400@gmail.com
- Update to version 0.20.0:
  + Save exported recipes to a file if sending mail fails.
  + Export all recipes to a file, from the app menu.
  + Dialogs now follow platform conventions for header bars.
  + Adapt to dark theme in some places.
  + Miscellaneous improvements on OS X.
  + Updated translations.
- Remove pkgconfig(appstream-glib) BuildRequires, no longer
  required.
* Mon Feb 27 2017 zaitor@opensuse.org
- Update to version 0.18.0:
  + A minor update, focusing on polish and performance.
  + Improve the UI for search by spiciness.
  + Speed up listing of recipes.
  + Add a “What's New” dialog.
  + New contributed recipes.
  + Updated translations.
- Add pkgconfig(appstream-glib) BuildRequires: New dependency.
* Sat Feb 25 2017 zaitor@opensuse.org
- Update to version 0.16.0:
  + This release brings mainly polish and robustness and crash
    fixes.
  + Introduce meson build support.
  + Be more robust with incomplete data.
  + Stylistic fixes to cooking mode.
  + Improve the behavior of timers in cooking mode.
  + Add categories for all recipes and new recipes.
  + Show more details for recipes.
  + More contributed recipes.
* Mon Feb 20 2017 firebird20@gmail.com
- Update to version 0.14.2:
  + A quick follow-up release to fix some issues with 0.14.0.
  + Fix problems with string extraction for translation.
  + Mark some forgotten strings as translatable.
  + Make notes in recipes translatable.
  + Add a missing file, cuisine.css.in.
  + Some stylistic improvements to contributed recipes.
  + Several minor bug fixes.
  + More contributed recipes.
- Changes from version 0.14.0:
  + This release changes the name of the binary and filesystem
    locations from 'recipes' to 'gnome-recipes'.
  + We are now using the email portal to send email, falling back
    to using a mailto: url if the portal is not available.
  + The fullscreen cooking mode has been refined.
  + Timers play a sound when they expire.
  + Edit and recontribute your contributed recipes.
  + More contributed recipes.
- Added pkgconfig(libcanberra0) BuildRequires: New dependencies.
- Rename package from recipes to gnome-recipes, following upstream.
  As the old package never made it out of any devel project space,
  we do not provide/obsolete the old names.
* Sun Feb 12 2017 zaitor@opensuse.org
- Update to version 0.12.0:
  + Recipes can be shared by email.
  + GNOME recipes has a mailing list, recipes-list@gnome.org.
  + The shopping list view has been refined.
  + Shopping lists can be shared by email as well.
* Wed Feb  8 2017 zaitor@opensuse.org
- Update to version 0.10.0:
  + This release focuses on completing the feature set for the 3.24
    release.
  + A new fullscreen cooking mode has been added.
  + Images can be viewed in fullscreen.
  + The user interface for adding notes has been refined.
  + Recipes can be searched for by their spiciness.
  + More contributed recipes.
* Sat Jan 21 2017 zaitor@opensuse.org
- Update to version 0.8.0:
  + This release focuses on completing and polishing existing
    features.
  + Multiple recipes can be exported an imported in one batch.
  + Deletion of recipes can be undone.
  + We inhibit screen blanking and suspend while a recipe is
    cooked.
  + There is a printable shopping list.
  + The ingredients page has been dropped for now.
  + Problems with exporting in a flatpak sandbox have been
    resolved.
* Tue Jan 10 2017 zaitor@opensuse.org
- Update to version 0.6.0:
  + This release focuses on localization. All included content
    should be properly translatable now, including recipe and chef
    descriptions and ingredients.
  + Recipe instructions can link to other recipes.
  + Recipe instructions can include links that switch to a
    particular image.
  + All recipe lists are now populated incrementally.
  + Recipe tiles look nicer now.
  + We show a 'built with GNOME Builder' logo in the About dialog.
  + The About dialog gained a 'System' tab.
- Changes from version 0.4.2:
  + This is a minor update that makes it possible to build without
    some of the dependencies, which helps for building on other
    platforms, such as OS X.
- Changes from version 0.4.0:
  + Support multiple ingredients lists per recipe.
  + Use 2 column layout for the edit page.
  + Use the new image viewer for editing as well.
  + Editing ingredients lists is much better.
  + Only allow editing your own recipes.
  + Move notes to the details page.
  + Allow markup (links) in chef descriptions.
  + Add spell checking in many places.
  + Updated translations.
- Add pkgconfig(json-glib-1.0) and pkgconfig(gspell-1)
  BuildRequires: New dependencies.
* Tue Dec 20 2016 badshah400@gmail.com
- Spec file cleanups.
* Mon Dec 19 2016 badshah400@gmail.com
- Initial package.
